@@ -10,18 +10,21 @@ Copyright (c) 2021-2022 MetoData.ai, Mohammad H Forouhesh
 This Module contains the implementation and encapsulation for Conditional Random Field classifier.
 """
 
+import pickle
 from typing import List, Tuple, Any
+from crf_pos.api import get_resources
 from crf_pos.pos_tagger.meta_tagger import MetaTagger
 from crf_pos.pos_tagger.utils import token2features
-import pickle
 
 
 class CrfPosTagger(MetaTagger):
     """
     Wapiti Part-of-Speech tagger encapsulation.
     """
-    def __init__(self, model_path) -> None:
+    def __init__(self) -> None:
         super().__init__()
+
+        model_path = get_resources(self.dir_path, resource_name='perpos.model')
         with open(model_path, 'rb') as resource:
             self.tagger = pickle.load(resource)
 
