@@ -1,5 +1,5 @@
 """
-Wapiti Classifier
+Meta Class for Classifiers
 
 ....................................................................................................
 MIT License
